@@ -137,6 +137,9 @@ class CoreOptions(optparse.OptionParser, object):
                          help='define custom connection handler')
         group.add_option("--conn-max-frame-size", type=int,
                          help='define custom maximum frame size in bytes (range: 512-4294967295)')
+        group.add_option("--conn-allowed-mechs", type="string",
+                         help='Define custom Allowed SASL mechanism list, '
+                              'separated by space e.g. "GSSAPI PLAIN"')
         self.add_option_group(group)
 
     def add_logging_options(self):
@@ -262,6 +265,8 @@ class SenderOptions(SRCoreOptions):
                          help="use the supplied id instead of generating one")
         group.add_option("-S", "--msg-subject", type="string",
                          help="specify a subject")
+        group.add_option("--msg-address", action="store", type="string",
+                         help="message address")
         group.add_option("--msg-reply-to", type="string",
                          help="specify reply-to address")
         group.add_option("--msg-durable", action="store", type="string", default="no",
@@ -293,12 +298,12 @@ class SenderOptions(SRCoreOptions):
                          metavar="NAME|~NAME",
                          action="callback", callback=to_unicode)
         group.add_option("--msg-content-from-file", action="store", type="string",
-                         help="AMQP message content loaded from file", metavar="<filename>")
+                         help="message content loaded from file", metavar="<filename>")
         group.add_option("--msg-content", action="callback", type="string",
-                         help="AMQP message content", metavar="<content>",
+                         help="message content", metavar="<content>",
                          callback=str_to_unicode)
         group.add_option("--msg-content-type", action="store", type="string",
-                         help="amqp message content type", metavar="<content-type>")
+                         help="message content type", metavar="<content-type>")
         group.add_option("--content-type", type="choice",
                          help="typecast the string arguments in msg-content* (default %default)",
                          choices=['string', 'int', 'long', 'float', 'bool'])
